==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/eo.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'eo', {
	button: {
		title: 'Butonaj atributoj',
		text: 'Teksto (Valoro)',
		type: 'Tipo',
		typeBtn: 'Butono',
		typeSbm: 'Validigi (submit)',
		typeRst: 'Remeti en la originstaton (Reset)'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Markobutonaj Atributoj',
		radioTitle: 'Radiobutonaj Atributoj',
		value: 'Valoro',
		selected: 'Selektita'
	},
	form: {
		title: 'Formularaj Atributoj',
		menu: 'Formularaj Atributoj',
		action: 'Ago',
		method: 'Metodo',
		encoding: 'Kodoprezento'
	},
	hidden: {
		title: 'Atributoj de Kaŝita Kampo',
		name: 'Nomo',
		value: 'Valoro'
	},
	select: {
		title: 'Atributoj de Elekta Kampo',
		selectInfo: 'Informoj pri la rulummenuo',
		opAvail: 'Elektoj Disponeblaj',
		value: 'Valoro',
		size: 'Grando',
		lines: 'Linioj',
		chkMulti: 'Permesi Plurajn Elektojn',
		opText: 'Teksto',
		opValue: 'Valoro',
		btnAdd: 'Aldoni',
		btnModify: 'Modifi',
		btnUp: 'Supren',
		btnDown: 'Malsupren',
		btnSetValue: 'Agordi kiel Elektitan Valoron',
		btnDelete: 'Forigi'
	},
	textarea: {
		title: 'Atributoj de Teksta Areo',
		cols: 'Kolumnoj',
		rows: 'Linioj'
	},
	textfield: {
		title: 'Atributoj de Teksta Kampo',
		name: 'Nomo',
		value: 'Valoro',
		charWidth: 'Signolarĝo',
		maxChars: 'Maksimuma Nombro da Signoj',
		type: 'Tipo',
		typeText: 'Teksto',
		typePass: 'Pasvorto',
		typeEmail: 'retpoŝtadreso',
		typeSearch: 'Serĉi',
		typeTel: 'Telefonnumero',
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/forms/lang/eo.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'eo', {
	button: {
		title: 'Butonaj atributoj',
		text: 'Teksto (Valoro)',
		type: 'Tipo',
		typeBtn: 'Butono',
		typeSbm: 'Validigi (submit)',
		typeRst: 'Remeti en la originstaton (Reset)'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Markobutonaj Atributoj',
		radioTitle: 'Radiobutonaj Atributoj',
		value: 'Valoro',
		selected: 'Selektita',
		required: 'Postulata'
	},
	form: {
		title: 'Formularaj Atributoj',
		menu: 'Formularaj Atributoj',
		action: 'Ago',
		method: 'Metodo',
		encoding: 'Kodoprezento'
	},
	hidden: {
		title: 'Atributoj de Kaŝita Kampo',
		name: 'Nomo',
		value: 'Valoro'
	},
	select: {
		title: 'Atributoj de Elekta Kampo',
		selectInfo: 'Informoj pri la rulummenuo',
		opAvail: 'Elektoj Disponeblaj',
		value: 'Valoro',
		size: 'Grando',
		lines: 'Linioj',
		chkMulti: 'Permesi Plurajn Elektojn',
		required: 'Postulata',
		opText: 'Teksto',
		opValue: 'Valoro',
		btnAdd: 'Aldoni',
		btnModify: 'Modifi',
		btnUp: 'Supren',
		btnDown: 'Malsupren',
		btnSetValue: 'Agordi kiel Elektitan Valoron',
		btnDelete: 'Forigi'
	},
	textarea: {
		title: 'Atributoj de Teksta Areo',
		cols: 'Kolumnoj',
		rows: 'Linioj'
	},
	textfield: {
		title: 'Atributoj de Teksta Kampo',
		name: 'Nomo',
		value: 'Valoro',
		charWidth: 'Signolarĝo',
		maxChars: 'Maksimuma Nombro da Signoj',
		required: 'Postulata',
		type: 'Tipo',
		typeText: 'Teksto',
		typePass: 'Pasvorto',
		typeEmail: 'retpoŝtadreso',
		typeSearch: 'Serĉi',
		typeTel: 'Telefonnumero',
		typeUrl: 'URL'
	}
} );
